@@ -18,12 +18,12 @@ from typing import Iterable, Tuple
 @click.option("--metadata", multiple=True, type=(str, str))
 @click.option(
     "--username",
-    required=True,
+    envvar='UTF_QUEUE_USERNAME',
     help="UTF queue username",
 )
 @click.option(
     "--password",
-    required=True,
+    envvar='UTF_QUEUE_PASSWORD',
     help="UTF queue password",
 )
 @click.option(
